MPCRTrsm: MPCR TRSM (Triangular Solve)

39-MPCR TRSMR Documentation

MPCR TRSM (Triangular Solve)

Description

Solves a triangular matrix equation.
performs:
op(A)*X=alpha*B
X*op(A)=alpha*B

Usage


## S4 method for signature 'Rcpp_MPCR'
MPCR.trsm(a,b,upper_triangle,transpose,side = 'L',alpha =1)
   

Arguments

a

MPCR Matrix A.

b

MPCR Matrix B.

upper_triangle

If the value is TRUE, the referenced part of matrix A corresponds to the upper triangle, with the opposite triangle assumed to contain zeros.

transpose

If TRUE, the transpose of A is used.

side

'R for Right side, 'L' for Left side.

alpha

Factor used for A, If alpha is zero, A is not accessed.

Value

An MPCR Matrix.

Examples

   ## Not run: 
   library(MPCR)
   a <- matrix(c(3.12393, -1.16854, -0.304408, -2.15901,
                 -1.16854, 1.86968, 1.04094, 1.35925,
                 -0.304408, 1.04094, 4.43374, 1.21072,
                 -2.15901, 1.35925, 1.21072, 5.57265), 4,4)


   mat_a <- as.MPCR(a,4,4,"single")
   mat_b <- as.MPCR(a,4,4,"double")

   MPCR.trsm(a=mat_a,b=mat_b,side='R',upper_triangle=TRUE,transpose=FALSE,alpha=1)
   print(mat_b)
   
## End(Not run)

MPCR documentation built on Aug. 23, 2026, 5:10 p.m.

Related to MPCRTrsm in MPCR...